[Libreoffice-commits] core.git: sc/source sc/workben sdext/source sd/source

Andrea Gelmini andrea.gelmini at gelma.net
Tue Sep 29 23:31:14 PDT 2015


 sc/source/ui/view/tabview.cxx                          |    8 ++++----
 sc/source/ui/view/tabview3.cxx                         |    2 +-
 sc/source/ui/view/tabview5.cxx                         |    2 +-
 sc/source/ui/view/tabvwsh4.cxx                         |    2 +-
 sc/source/ui/view/tabvwshb.cxx                         |    2 +-
 sc/workben/addin.cxx                                   |    2 +-
 sd/source/core/CustomAnimationEffect.cxx               |    2 +-
 sd/source/ui/accessibility/AccessibleViewForwarder.cxx |    2 +-
 sd/source/ui/dlg/brkdlg.cxx                            |    2 +-
 sdext/source/pdfimport/tree/style.cxx                  |    2 +-
 sdext/source/pdfimport/xpdfwrapper/pdfioutdev_gpl.cxx  |    2 +-
 sdext/source/presenter/PresenterNotesView.hxx          |    2 +-
 sdext/source/presenter/PresenterPaneBorderPainter.hxx  |    2 +-
 sdext/source/presenter/PresenterPaneFactory.hxx        |    4 ++--
 sdext/source/presenter/PresenterSlideShowView.hxx      |    2 +-
 15 files changed, 19 insertions(+), 19 deletions(-)

New commits:
commit 185f207ef17d58ea81d0c17c1a37cf14647cc71a
Author: Andrea Gelmini <andrea.gelmini at gelma.net>
Date:   Tue Sep 29 17:58:05 2015 +0200

    Fix typos
    
    Change-Id: I3ea8a90f0ec917b4e26335fcd31a5f7e0888589e
    Reviewed-on: https://gerrit.libreoffice.org/18972
    Reviewed-by: Samuel Mehrbrodt <Samuel.Mehrbrodt at cib.de>
    Tested-by: Samuel Mehrbrodt <Samuel.Mehrbrodt at cib.de>

diff --git a/sc/source/ui/view/tabview.cxx b/sc/source/ui/view/tabview.cxx
index 87d0f09..88787fd 100644
--- a/sc/source/ui/view/tabview.cxx
+++ b/sc/source/ui/view/tabview.cxx
@@ -527,7 +527,7 @@ void ScTabView::DoResize( const Point& rOffset, const Size& rSize, bool bInner )
         }
     }
 
-    //  SetDragRectPixel also whithout Scrollbars etc., when already split
+    //  SetDragRectPixel also without Scrollbars etc., when already split
     if ( bHScroll || aViewData.GetHSplitMode() != SC_SPLIT_NONE )
         pHSplitter->SetDragRectPixel(
             Rectangle( nPosX, nPosY, nPosX+nSizeX, nPosY+nSizeY ), pFrameWin );
@@ -1132,7 +1132,7 @@ IMPL_LINK_TYPED( ScTabView, ScrollHdl, ScrollBar*, pScroll, void )
             break;
         case SCROLL_DRAG:
             {
-                // only scroll in the corret direction, do not jitter around hidden ranges
+                // only scroll in the correct direction, do not jitter around hidden ranges
                 long nScrollMin = 0;        // simulate RangeMin
                 if ( aViewData.GetHSplitMode()==SC_SPLIT_FIX && pScroll == aHScrollRight.get() )
                     nScrollMin = aViewData.GetFixPosX();
@@ -1352,8 +1352,8 @@ namespace
 SCROW lcl_LastVisible( ScViewData& rViewData )
 {
     // If many rows are hidden at end of the document (what kind of idiot does that?),
-    // then there should not be a switch to wide row headers beacause of this
-    //! as a member to the document ???
+    // then there should not be a switch to wide row headers because of this
+    //! as a member to the document???
     ScDocument* pDoc = rViewData.GetDocument();
     SCTAB nTab = rViewData.GetTabNo();
 
diff --git a/sc/source/ui/view/tabview3.cxx b/sc/source/ui/view/tabview3.cxx
index 1b84422..fc5df52 100644
--- a/sc/source/ui/view/tabview3.cxx
+++ b/sc/source/ui/view/tabview3.cxx
@@ -1883,7 +1883,7 @@ void ScTabView::KillEditView( bool bNoPaint )
     {
 //      should be done like this, so that Sfx notice it, but it does not work:
 //!     aViewData.GetViewShell()->GetViewFrame()->GetWindow().GrabFocus();
-//      therfore first like this:
+//      therefore first like this:
         GetActiveWin()->GrabFocus();
     }
 
diff --git a/sc/source/ui/view/tabview5.cxx b/sc/source/ui/view/tabview5.cxx
index c3f5516..9887de0 100644
--- a/sc/source/ui/view/tabview5.cxx
+++ b/sc/source/ui/view/tabview5.cxx
@@ -472,7 +472,7 @@ void ScTabView::DrawEnableAnim(bool bSet)
     sal_uInt16 i;
     if ( pDrawView )
     {
-        //  dont start animations if display of graphics is disabled
+        //  don't start animations if display of graphics is disabled
         //  graphics are controlled by VOBJ_TYPE_OLE
         if ( bSet && aViewData.GetOptions().GetObjMode(VOBJ_TYPE_OLE) == VOBJ_MODE_SHOW )
         {
diff --git a/sc/source/ui/view/tabvwsh4.cxx b/sc/source/ui/view/tabvwsh4.cxx
index 408687a..67d5a39 100644
--- a/sc/source/ui/view/tabvwsh4.cxx
+++ b/sc/source/ui/view/tabvwsh4.cxx
@@ -1628,7 +1628,7 @@ void ScTabViewShell::Construct( TriState nForceDesignMode )
     pDocSh->SetUpdateEnabled(false);
 
     if ( GetViewFrame()->GetFrame().IsInPlace() )
-        UpdateHeaderWidth(); // The implace activation requires headers to be calculated
+        UpdateHeaderWidth(); // The inplace activation requires headers to be calculated
 
     SvBorder aBorder;
     GetBorderSize( aBorder, Size() );
diff --git a/sc/source/ui/view/tabvwshb.cxx b/sc/source/ui/view/tabvwshb.cxx
index 3dc426e..c92fc55 100644
--- a/sc/source/ui/view/tabvwshb.cxx
+++ b/sc/source/ui/view/tabvwshb.cxx
@@ -265,7 +265,7 @@ void ScTabViewShell::ExecDrawIns(SfxRequest& rReq)
         UpdateInputHandler();
     }
 
-    // inertion of border for Chart is cancelled:
+    // insertion of border for Chart is cancelled:
     FuPoor* pPoor = GetDrawFuncPtr();
     if ( pPoor && pPoor->GetSlotID() == SID_DRAW_CHART )
         GetViewData().GetDispatcher().Execute(SID_DRAW_CHART, SfxCallMode::SLOT | SfxCallMode::RECORD);
diff --git a/sc/workben/addin.cxx b/sc/workben/addin.cxx
index 60089b3..4ec3338 100644
--- a/sc/workben/addin.cxx
+++ b/sc/workben/addin.cxx
@@ -369,7 +369,7 @@ sal_Int32 SAL_CALL ScTestAddIn::getColorValue( const ::com::sun::star::uno::Refe
         long nRet = -1;
         uno::Any aTrans = xProp->getPropertyValue( L"IsCellBackgroundTransparent" );
         sal_Bool bIsTrans;
-        aTrans >>= bIsTrans;        //! dont use >>= for BOOL
+        aTrans >>= bIsTrans;        //! don't use >>= for BOOL
         if (!bIsTrans)
         {
             uno::Any aCol = xProp->getPropertyValue( L"CellBackColor" );
diff --git a/sd/source/core/CustomAnimationEffect.cxx b/sd/source/core/CustomAnimationEffect.cxx
index 898bd88..aac67ea 100644
--- a/sd/source/core/CustomAnimationEffect.cxx
+++ b/sd/source/core/CustomAnimationEffect.cxx
@@ -2675,7 +2675,7 @@ void EffectSequenceHelper::setAnimateForm( CustomAnimationTextGroupPtr pTextGrou
         }
         else
         {
-            // readd the rest to the group again
+            // read the rest to the group again
             while( aIter != aEnd )
             {
                 CustomAnimationEffectPtr pEffect( (*aIter++) );
diff --git a/sd/source/ui/accessibility/AccessibleViewForwarder.cxx b/sd/source/ui/accessibility/AccessibleViewForwarder.cxx
index 8809a74..0a6ed2a 100644
--- a/sd/source/ui/accessibility/AccessibleViewForwarder.cxx
+++ b/sd/source/ui/accessibility/AccessibleViewForwarder.cxx
@@ -68,7 +68,7 @@ Rectangle AccessibleViewForwarder::GetVisibleArea() const
     return aVisibleArea;
 }
 
-/** Tansform the given point into pixel coordinates.  After the pixel
+/** Transform the given point into pixel coordinates.  After the pixel
     coordinates of the window origin are added to make the point coordinates
     absolute.
 */
diff --git a/sd/source/ui/dlg/brkdlg.cxx b/sd/source/ui/dlg/brkdlg.cxx
index adf53ce..b6a117f 100644
--- a/sd/source/ui/dlg/brkdlg.cxx
+++ b/sd/source/ui/dlg/brkdlg.cxx
@@ -57,7 +57,7 @@ BreakDlg::BreakDlg(
     mpProgress = new SfxProgress( pShell, SD_RESSTR(STR_BREAK_METAFILE), nSumActionCount*3 );
 
     pProgrInfo = new SvdProgressInfo( LINK(this, BreakDlg, UpDate) );
-    // every action is editedt 3 times in DoImport()
+    // every action is edited 3 times in DoImport()
     pProgrInfo->Init( nSumActionCount*3, nObjCount );
 
     pDrView = _pDrView;
diff --git a/sdext/source/pdfimport/tree/style.cxx b/sdext/source/pdfimport/tree/style.cxx
index 0eba65d..cc11bd4 100644
--- a/sdext/source/pdfimport/tree/style.cxx
+++ b/sdext/source/pdfimport/tree/style.cxx
@@ -109,7 +109,7 @@ sal_Int32 StyleContainer::setProperties( sal_Int32 nStyleId, const PropertyMap&
         }
         else
         {
-            // decrease refcound on old instance
+            // decrease refcount on old instance
             it->second.RefCount--;
             // acquire new HashedStyle
             HashedStyle aSearchStyle;
diff --git a/sdext/source/pdfimport/xpdfwrapper/pdfioutdev_gpl.cxx b/sdext/source/pdfimport/xpdfwrapper/pdfioutdev_gpl.cxx
index b7c47d8..b319afe 100644
--- a/sdext/source/pdfimport/xpdfwrapper/pdfioutdev_gpl.cxx
+++ b/sdext/source/pdfimport/xpdfwrapper/pdfioutdev_gpl.cxx
@@ -58,7 +58,7 @@
 /* SYNC STREAMS
    ============
 
-   We stream human-readble tokens to stdout, and binary data (fonts,
+   We stream human-readable tokens to stdout, and binary data (fonts,
    bitmaps) to g_binary_out. Another process reads from those pipes, and
    there lies the rub: things can deadlock, if the two involved
    processes access the pipes in different order. At any point in
diff --git a/sdext/source/presenter/PresenterNotesView.hxx b/sdext/source/presenter/PresenterNotesView.hxx
index d6fe3da..687311cc 100644
--- a/sdext/source/presenter/PresenterNotesView.hxx
+++ b/sdext/source/presenter/PresenterNotesView.hxx
@@ -77,7 +77,7 @@ public:
     /** Typically called from setCurrentSlide() with the notes page that is
         associeted with the slide given to setCurrentSlide().
 
-        Iterates over all text shapes on the given notes page and diplays
+        Iterates over all text shapes on the given notes page and displays
         the concatenated text of these.
     */
     void SetSlide (
diff --git a/sdext/source/presenter/PresenterPaneBorderPainter.hxx b/sdext/source/presenter/PresenterPaneBorderPainter.hxx
index 7632fa8..1301065 100644
--- a/sdext/source/presenter/PresenterPaneBorderPainter.hxx
+++ b/sdext/source/presenter/PresenterPaneBorderPainter.hxx
@@ -68,7 +68,7 @@ public:
         const css::awt::Rectangle& rInnerBox,
         const css::drawing::framework::BorderType eBorderType) const;
 
-    /** Transorm the outer bounding box of a window to the bounding box of
+    /** Transform the outer bounding box of a window to the bounding box of
         the inner content area.
         @param rsPaneURL
             Specifies the pane style that is used to determine the border sizes.
diff --git a/sdext/source/presenter/PresenterSlideShowView.hxx b/sdext/source/presenter/PresenterSlideShowView.hxx
index 05c3352b..1c4dfef 100644
--- a/sdext/source/presenter/PresenterSlideShowView.hxx
+++ b/sdext/source/presenter/PresenterSlideShowView.hxx
@@ -228,7 +228,7 @@ private:
     */
     double mnPageAspectRatio;
 
-    /** This broadcast helper is used to notify listeners registed to a
+    /** This broadcast helper is used to notify listeners registered to a
         SlideShowView object.
     */
     ::cppu::OBroadcastHelper maBroadcaster;


More information about the Libreoffice-commits mailing list
diff --git a/sdext/source/presenter/PresenterPaneFactory.hxx b/sdext/source/presenter/PresenterPaneFactory.hxx
index a3c72a5..3821db7 100644
--- a/sdext/source/presenter/PresenterPaneFactory.hxx
+++ b/sdext/source/presenter/PresenterPaneFactory.hxx
@@ -43,9 +43,9 @@ namespace {
     > PresenterPaneFactoryInterfaceBase;
 }
 
 /** The PresenerPaneFactory provides a fixed set of panes.
 
-    In order to make the presener screen more easily extendable in the
+    In order to make the presenter screen more easily extendable in the
     future the set of supported panes could be made extendable on demand.
 */
 class PresenterPaneFactory
@@ -43,9 +43,9 @@ namespace {
 }
 
-/** The PresenerPaneFactory provides a fixed set of panes.
+/** The PresenterPaneFactory provides a fixed set of panes.
 